@@ -1,2 +1,4 @@
 from .models.conformer import ConformerEncoder, Conformer
-from .models.contextnet import ContextNetEncoder, ContextNet
\ No newline at end of file
+from .models.contextnet import ContextNetEncoder, ContextNet
+from .utils.weights import load_pretrain
+from .version import __version__
\ No newline at end of file
