@@ -7,7 +7,7 @@ from ..layers.positional_encoding import PositionalEncoding, PositionalEncodingC
 from ..layers.subsampling import Conv2dSubsampling, VggSubsampling
 
 L2 = tf.keras.regularizers.l2(1e-6)
-URL = 'https://drive.google.com/file/d/1uwF_KJkcCVG44u5Be2Qb4Y_KJSPt39YB/view?usp=sharing'
+URL = "https://github.com/awsaf49/audio_classification_models/releases/download/v1.0.8/conformer-encoder.h5"
 
 class FFModule(tf.keras.layers.Layer):
     def __init__(
@@ -418,7 +418,7 @@ def Conformer(input_shape = (128, 80, 1),num_classes=1, final_activation='sigmoi
     backbone = ConformerEncoder()
     out = backbone(inp)
     if pretrain:
-        weights.load_pretrain(backbone, url=URL, fname='conformer-encoder.h5')
+        weights.load_pretrain(backbone, url=URL)
     out = tf.keras.layers.GlobalAveragePooling1D()(out)
     out = tf.keras.layers.Dense(32, activation='selu')(out)
     out = tf.keras.layers.Dense(num_classes, activation=final_activation)(out)
